diff --git a/channels/chan_dahdi.c b/channels/chan_dahdi.c
index 5bd2bd9..c6a6761 100644
--- a/channels/chan_dahdi.c
+++ b/channels/chan_dahdi.c
@@ -3853,13 +3853,11 @@ static struct ast_frame *dahdi_handle_event(struct ast_channel *ast)
 	}
 
 	switch (res) {
-#ifdef DAHDI_EVENT_EC_DISABLED
 		case DAHDI_EVENT_EC_DISABLED:
 			if (option_verbose > 2) 
 				ast_verbose(VERBOSE_PREFIX_3 "Channel %d echo canceler disabled due to CED detection\n", p->channel);
 			p->echocanon = 0;
 			break;
-#endif
 		case DAHDI_EVENT_BITSCHANGED:
 			ast_log(LOG_WARNING, "Recieved bits changed on %s signalling?\n", sig2str(p->sig));
 		case DAHDI_EVENT_PULSE_START:
@@ -4236,7 +4234,6 @@ static struct ast_frame *dahdi_handle_event(struct ast_channel *ast)
 				ast_log(LOG_WARNING, "Don't know how to handle ring/off hook for signalling %d\n", p->sig);
 			}
 			break;
-#ifdef DAHDI_EVENT_RINGBEGIN
 		case DAHDI_EVENT_RINGBEGIN:
 			switch (p->sig) {
 			case SIG_FXSLS:
@@ -4248,7 +4245,6 @@ static struct ast_frame *dahdi_handle_event(struct ast_channel *ast)
 				break;
 			}
 			break;
-#endif			
 		case DAHDI_EVENT_RINGEROFF:
 			if (p->inalarm) break;
 			if ((p->radio || (p->oprmode < 0))) break;
@@ -6314,12 +6310,10 @@ static void *ss_thread(void *data)
 							ast_log(LOG_NOTICE, "Got event %d (%s)...\n", res, event2str(res));
 
 							if (p->cid_signalling == CID_SIG_V23_JP) {
-#ifdef DAHDI_EVENT_RINGBEGIN
 								if (res == DAHDI_EVENT_RINGBEGIN) {
 									res = dahdi_set_hook(p->subs[SUB_REAL].dfd, DAHDI_OFFHOOK);
 									usleep(1);
 								}
-#endif
 							} else {
 								res = 0;
 								break;
@@ -10345,11 +10339,9 @@ static int dahdi_show_channel(int fd, int argc, char **argv)
 				if (!ioctl(tmp->subs[SUB_REAL].dfd, DAHDI_GETCONF, &ci)) {
 					ast_cli(fd, "Actual Confinfo: Num/%d, Mode/0x%04x\n", ci.confno, ci.confmode);
 				}
-#ifdef DAHDI_GETCONFMUTE
 				if (!ioctl(tmp->subs[SUB_REAL].dfd, DAHDI_GETCONFMUTE, &x)) {
 					ast_cli(fd, "Actual Confmute: %s\n", x ? "Yes" : "No");
 				}
-#endif
 				if (ioctl(tmp->subs[SUB_REAL].dfd, DAHDI_GET_PARAMS, &ps) < 0) {
 					ast_log(LOG_WARNING, "Failed to get parameters on channel %d: %s\n", tmp->channel, strerror(errno));
 				} else {
@@ -11992,7 +11984,7 @@ static int reload(void)
  * AST_MODULE_INFO(, , "DAHDI Telephony"
  */
 
-#ifdef DAHDI_PRI
+#ifdef HAVE_PRI
 #define tdesc "DAHDI Telephony w/PRI"
 #else
 #define tdesc "DAHDI Telephony"
diff --git a/include/asterisk/dahdi_compat.h b/include/asterisk/dahdi_compat.h
index 2270237..73b94a8 100644
--- a/include/asterisk/dahdi_compat.h
+++ b/include/asterisk/dahdi_compat.h
@@ -44,7 +44,9 @@
 #define DAHDI_AUDIOMODE ZT_AUDIOMODE
 #define dahdi_bufferinfo zt_bufferinfo
 #define DAHDI_CHANNO ZT_CHANNO
+#ifdef ZT_CHECK_HOOKSTATE
 #define DAHDI_CHECK_HOOKSTATE ZT_CHECK_HOOKSTATE
+#endif
 #define DAHDI_CONF_CONF ZT_CONF_CONF
 #define DAHDI_CONF_CONFANN ZT_CONF_CONFANN
 #define DAHDI_CONF_CONFANNMON ZT_CONF_CONFANNMON
@@ -119,7 +121,6 @@
 #define dahdi_params zt_params
 #define DAHDI_POLICY_IMMEDIATE ZT_POLICY_IMMEDIATE
 #define DAHDI_POLICY_WHEN_FULL ZT_POLICY_WHEN_FULL
-#define DAHDI_PRI ZT_PRI
 #define DAHDI_RING ZT_RING
 #define DAHDI_RINGOFF ZT_RINGOFF
 #define DAHDI_SENDTONE ZT_SENDTONE
@@ -159,7 +160,9 @@
 #define DAHDI_TIMERPONG ZT_TIMERPONG
 #define DAHDI_TONE_BUSY ZT_TONE_BUSY
 #define DAHDI_TONE_CONGESTION ZT_TONE_CONGESTION
+#ifdef ZT_TONEDETECT
 #define DAHDI_TONEDETECT ZT_TONEDETECT
+#endif
 #define DAHDI_TONEDETECT_MUTE ZT_TONEDETECT_MUTE
 #define DAHDI_TONEDETECT_ON ZT_TONEDETECT_ON
 #define DAHDI_TONE_DIALRECALL ZT_TONE_DIALRECALL
